# Usage of this Module

Create a new file with any name you want!!

then,

**Ensure that turtle module is installed in your machine**

first import this as_doraemon module

then,

use below functions to draw doraemon

head() <br/>
belt()	<br/>
face()	<br/>
nose()	<br/>
mouth()	<br/>
whisker()	<br/>
body()	<br/>
arms()	<br/>
pocket()	<br/>
bell()	<br/>
black_eyes()	<br/>

### Sample Program
```
import as_doraemon as s

s.head()
s.belt()
s.face()
s.nose()
s.mouth()
s.whisker()
s.body()
s.arms()
s.pocket()
s.bell()
s.black_eyes()
s.ht()
s.done()

```


## For more info:
https://www.youtube.com/channel/UCfthEj3oCLiFakXtSzhZ7Dw